@@ -3,223 +3,243 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
-        <location filename="mainwindow.cpp" line="49"/>
-        <location filename="mainwindow.cpp" line="113"/>
-        <location filename="mainwindow.cpp" line="788"/>
-        <location filename="mainwindow.cpp" line="925"/>
-        <location filename="ui_mainwindow.h" line="534"/>
+        <location filename="mainwindow.cpp" line="57"/>
+        <location filename="mainwindow.cpp" line="125"/>
+        <location filename="mainwindow.cpp" line="850"/>
+        <location filename="ui_mainwindow.h" line="549"/>
         <source>Snapshot</source>
         <translation>Snapshot</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="27"/>
-        <location filename="ui_mainwindow.h" line="535"/>
+        <location filename="mainwindow.ui" line="30"/>
+        <location filename="ui_mainwindow.h" line="550"/>
         <source>Snapshot location:</source>
         <translation>Localização da imagem do disco:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="40"/>
-        <location filename="ui_mainwindow.h" line="536"/>
+        <location filename="mainwindow.ui" line="43"/>
+        <location filename="ui_mainwindow.h" line="551"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot é um utilitário que cria uma imagem carregável (bootable) do sistema, que pode ser usada para guardar ou para distribuir. Permite que se trabalhe com aplicações pouco pesadas enquanto está em execução.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="50"/>
-        <location filename="ui_mainwindow.h" line="537"/>
+        <location filename="mainwindow.ui" line="53"/>
+        <location filename="ui_mainwindow.h" line="552"/>
         <source>Used space on / (root) and /home partitions:</source>
         <translation>Espaço usado nas partições / (root) e /home :</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="155"/>
-        <location filename="mainwindow.cpp" line="739"/>
-        <location filename="ui_mainwindow.h" line="541"/>
+        <location filename="mainwindow.ui" line="158"/>
+        <location filename="mainwindow.cpp" line="796"/>
+        <location filename="ui_mainwindow.h" line="556"/>
         <source>Snapshot name:</source>
         <translation>Nome do Snapshot:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="162"/>
-        <location filename="ui_mainwindow.h" line="542"/>
+        <location filename="mainwindow.ui" line="165"/>
+        <location filename="ui_mainwindow.h" line="557"/>
         <source>Select a different snapshot directory</source>
         <translation>Selecione um diretório de snapshot diferente</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="211"/>
-        <location filename="mainwindow.ui" line="229"/>
-        <location filename="mainwindow.ui" line="262"/>
-        <location filename="ui_mainwindow.h" line="544"/>
-        <location filename="ui_mainwindow.h" line="545"/>
-        <location filename="ui_mainwindow.h" line="546"/>
+        <location filename="mainwindow.ui" line="215"/>
+        <location filename="ui_mainwindow.h" line="561"/>
+        <source>lz4</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="220"/>
+        <location filename="ui_mainwindow.h" line="562"/>
+        <source>lzo</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="225"/>
+        <location filename="ui_mainwindow.h" line="563"/>
+        <source>gzip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="230"/>
+        <location filename="ui_mainwindow.h" line="564"/>
+        <source>xz</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="238"/>
+        <location filename="mainwindow.ui" line="313"/>
+        <location filename="ui_mainwindow.h" line="566"/>
+        <location filename="ui_mainwindow.h" line="568"/>
         <source>TextLabel</source>
         <translation>Rótulo de texto</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="275"/>
-        <location filename="ui_mainwindow.h" line="547"/>
-        <source>Edit Configuration File</source>
-        <translation>Editar o arquivo de configuração</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="309"/>
-        <location filename="ui_mainwindow.h" line="548"/>
+        <location filename="mainwindow.ui" line="281"/>
+        <location filename="ui_mainwindow.h" line="567"/>
         <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
         <translation>Algumas directorias também podem ser excluídas marcando as escolhas comuns, abaixo, ou clicando no botão para editar directamente /usr/lib/iso-snapshot/snapshot-exclude.list.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="334"/>
-        <location filename="ui_mainwindow.h" line="549"/>
+        <location filename="mainwindow.ui" line="338"/>
+        <location filename="ui_mainwindow.h" line="569"/>
         <source>Downloads</source>
         <translation>Transferências</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
-        <location filename="ui_mainwindow.h" line="550"/>
+        <location filename="mainwindow.ui" line="345"/>
+        <location filename="ui_mainwindow.h" line="570"/>
         <source>Documents</source>
         <translation>Documentos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
-        <location filename="ui_mainwindow.h" line="551"/>
+        <location filename="mainwindow.ui" line="352"/>
+        <location filename="ui_mainwindow.h" line="571"/>
         <source>All of the above</source>
         <translation>Tudo os itens acima</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="355"/>
-        <location filename="ui_mainwindow.h" line="552"/>
+        <location filename="mainwindow.ui" line="359"/>
+        <location filename="ui_mainwindow.h" line="572"/>
         <source>Pictures</source>
         <translation>Fotos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="362"/>
-        <location filename="ui_mainwindow.h" line="553"/>
+        <location filename="mainwindow.ui" line="366"/>
+        <location filename="ui_mainwindow.h" line="573"/>
         <source>Music</source>
         <translation>Músicas</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="369"/>
-        <location filename="ui_mainwindow.h" line="554"/>
+        <location filename="mainwindow.ui" line="373"/>
+        <location filename="ui_mainwindow.h" line="574"/>
         <source>Desktop</source>
         <translation>Ambiente de trabalho</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="376"/>
-        <location filename="ui_mainwindow.h" line="555"/>
+        <location filename="mainwindow.ui" line="380"/>
+        <location filename="ui_mainwindow.h" line="575"/>
         <source>Videos</source>
         <translation>Vídeos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="392"/>
-        <location filename="ui_mainwindow.h" line="556"/>
-        <source>Edit Exclusion File</source>
-        <translation>Editar o arquivo de exclusão</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="422"/>
-        <location filename="ui_mainwindow.h" line="558"/>
+        <location filename="mainwindow.ui" line="418"/>
+        <location filename="ui_mainwindow.h" line="577"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the antiX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esta opção restabelecerá as palavras-passe&amp;quot;demo&amp;quot; e &amp;quot;root&amp;quot; para as predefinições do Linux antiX e não copiará quaisquer contas pessoais criadas.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="425"/>
-        <location filename="ui_mainwindow.h" line="560"/>
+        <location filename="mainwindow.ui" line="421"/>
+        <location filename="ui_mainwindow.h" line="579"/>
         <source>Resetting accounts (for distribution to others)</source>
         <translation>Restablecer contas (para distribuir a outros)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="432"/>
-        <location filename="ui_mainwindow.h" line="561"/>
+        <location filename="mainwindow.ui" line="428"/>
+        <location filename="ui_mainwindow.h" line="580"/>
         <source>Type of snapshot:</source>
         <translation>Tipo de snapshot:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="439"/>
-        <location filename="ui_mainwindow.h" line="562"/>
+        <location filename="mainwindow.ui" line="435"/>
+        <location filename="ui_mainwindow.h" line="581"/>
         <source>Preserving accounts (for personal backup)</source>
         <translation>Preservar contas (para segurança pessoal)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="551"/>
-        <location filename="ui_mainwindow.h" line="565"/>
-        <source>Quit application</source>
-        <translation>Sair da aplicação</translation>
+        <location filename="mainwindow.ui" line="461"/>
+        <location filename="ui_mainwindow.h" line="582"/>
+        <source>ISO compression scheme:</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="554"/>
-        <location filename="mainwindow.cpp" line="931"/>
-        <location filename="ui_mainwindow.h" line="567"/>
-        <source>Cancel</source>
-        <translation>Cancelar</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="561"/>
-        <location filename="ui_mainwindow.h" line="568"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
+        <location filename="mainwindow.ui" line="474"/>
+        <location filename="ui_mainwindow.h" line="583"/>
+        <source>Edit Exclusion File</source>
+        <translation>Editar o arquivo de exclusão</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="571"/>
-        <location filename="ui_mainwindow.h" line="570"/>
+        <location filename="ui_mainwindow.h" line="586"/>
         <source>Display help </source>
         <translation>Exibir a ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="574"/>
-        <location filename="ui_mainwindow.h" line="572"/>
+        <location filename="ui_mainwindow.h" line="588"/>
         <source>Help</source>
         <translation>Ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="581"/>
-        <location filename="ui_mainwindow.h" line="573"/>
+        <location filename="ui_mainwindow.h" line="589"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="604"/>
-        <location filename="ui_mainwindow.h" line="575"/>
+        <location filename="mainwindow.ui" line="632"/>
+        <location filename="ui_mainwindow.h" line="592"/>
         <source>About this application</source>
         <translation>Sobre esta aplicação</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="607"/>
-        <location filename="ui_mainwindow.h" line="577"/>
+        <location filename="mainwindow.ui" line="635"/>
+        <location filename="ui_mainwindow.h" line="594"/>
         <source>About...</source>
         <translation>Sobre...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="614"/>
-        <location filename="ui_mainwindow.h" line="578"/>
+        <location filename="mainwindow.ui" line="642"/>
+        <location filename="ui_mainwindow.h" line="595"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="652"/>
-        <location filename="ui_mainwindow.h" line="580"/>
+        <location filename="mainwindow.ui" line="658"/>
+        <location filename="ui_mainwindow.h" line="597"/>
+        <source>Quit application</source>
+        <translation>Sair da aplicação</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="661"/>
+        <location filename="ui_mainwindow.h" line="599"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="668"/>
+        <location filename="ui_mainwindow.h" line="600"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="684"/>
+        <location filename="ui_mainwindow.h" line="601"/>
         <source>Next</source>
         <translation>Próximo</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="678"/>
-        <location filename="ui_mainwindow.h" line="582"/>
+        <location filename="mainwindow.ui" line="726"/>
+        <location filename="ui_mainwindow.h" line="603"/>
         <source>Back</source>
         <translation>Voltar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="203"/>
+        <location filename="mainwindow.cpp" line="239"/>
         <source>Used space on / (root): </source>
         <translation>Espaço usado em / (root):</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="206"/>
+        <location filename="mainwindow.cpp" line="242"/>
         <source>Used space on /home: </source>
         <translation>Espaço usado em /home:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="224"/>
+        <location filename="mainwindow.cpp" line="260"/>
         <source>Free space on %1, where snapshot folder is placed: </source>
         <translation>Espaço livre em %1, onde a pasta de imagens está colocada:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="226"/>
+        <location filename="mainwindow.cpp" line="262"/>
         <source>The free space should be sufficient to hold the compressed data from / and /home
 
       If necessary, you can create more available space
@@ -234,206 +254,218 @@ removendo imagens anteriores e cópias guardadas:
 </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="246"/>
-        <location filename="mainwindow.cpp" line="247"/>
+        <location filename="mainwindow.cpp" line="282"/>
+        <location filename="mainwindow.cpp" line="283"/>
         <source>Installing </source>
         <translation>Instalando</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
-        <location filename="mainwindow.cpp" line="555"/>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="592"/>
+        <location filename="mainwindow.cpp" line="608"/>
+        <location filename="mainwindow.cpp" line="802"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
+        <location filename="mainwindow.cpp" line="291"/>
         <source>Could not install </source>
         <translation>Não foi instalado</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="321"/>
         <source>Building new initrd...</source>
         <translation>Construindo novo initrd...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="347"/>
         <source>Copying the new-iso filesystem...</source>
         <translation>Copiar o sistema de arquivos da nova imagem iso...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
+        <location filename="mainwindow.cpp" line="589"/>
         <source>Squashing filesystem...</source>
         <translation>Comprimir o sistema de arquivos...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="555"/>
+        <location filename="mainwindow.cpp" line="592"/>
         <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
         <translation>Não foi possível criar o arquivo linuxfs; verifique se há espaço suficiente na partição de destino.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="569"/>
+        <location filename="mainwindow.cpp" line="606"/>
         <source>Creating CD/DVD image file...</source>
         <translation>Criar o arquivo de imagem de CD/DVD...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="608"/>
         <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
         <translation>Não foi possível criar o arquivo ISO; verifique há espaço suficiente na partição de destino.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="578"/>
+        <location filename="mainwindow.cpp" line="615"/>
         <source>Making hybrid iso</source>
         <translation>Criar imagem iso híbrida</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="599"/>
+        <location filename="mainwindow.cpp" line="628"/>
+        <source>MX Snapshot completed sucessfully!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="629"/>
+        <location filename="mainwindow.cpp" line="630"/>
+        <source>Snapshot took %1 to finish.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="631"/>
+        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="644"/>
         <source>Making md5sum</source>
         <translation>Criar md5sum</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="622"/>
+        <location filename="mainwindow.cpp" line="668"/>
         <source>Cleaning...</source>
         <translation>Limpando...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="635"/>
-        <location filename="mainwindow.cpp" line="998"/>
+        <location filename="mainwindow.cpp" line="682"/>
+        <location filename="mainwindow.cpp" line="988"/>
         <source>Done</source>
         <translation>Feito</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="713"/>
+        <location filename="mainwindow.cpp" line="770"/>
         <source>Please wait.</source>
         <translation>Aguarde</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="715"/>
+        <location filename="mainwindow.cpp" line="772"/>
         <source>Please wait. Calculating used disk space...</source>
         <translation>Aguarde. Calculando o espaço em disco usado...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="730"/>
+        <location filename="mainwindow.cpp" line="787"/>
         <source>Settings</source>
         <translation>Configuração</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="736"/>
+        <location filename="mainwindow.cpp" line="793"/>
         <source>Snapshot will use the following settings:*</source>
         <translation>A imagem usará as seguintes definições:*</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="738"/>
+        <location filename="mainwindow.cpp" line="795"/>
         <source>- Snapshot directory:</source>
         <translation>- diretório de imagens:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="740"/>
+        <location filename="mainwindow.cpp" line="797"/>
         <source>- Kernel to be used:</source>
         <translation>Núcleo (kernel) a ser usado:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="741"/>
-        <source>*These settings can be changed by editing: </source>
-        <translation>*Estas definições podem ser alteradas editando:</translation>
+        <location filename="mainwindow.cpp" line="803"/>
+        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="746"/>
+        <location filename="mainwindow.cpp" line="807"/>
         <source>Final chance</source>
         <translation>Última hipótese</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="747"/>
+        <location filename="mainwindow.cpp" line="808"/>
         <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
         <translation>O Snapshot tem agora toda a informação de que precisa para criar uma imagem ISO do sistema em uso.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="748"/>
+        <location filename="mainwindow.cpp" line="809"/>
         <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
         <translation>Demorará algum tempo para terminar, dependendo do tamanho do sistema instalado e da capacidade do computador.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="749"/>
+        <location filename="mainwindow.cpp" line="810"/>
         <source>OK to start?</source>
         <translation>Iniciar?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="757"/>
+        <location filename="mainwindow.cpp" line="819"/>
         <source>Output</source>
         <translation>Resultado</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="764"/>
+        <location filename="mainwindow.cpp" line="826"/>
         <source>Edit Boot Menu</source>
         <translation>Editar o Menu de Iniciação</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="765"/>
+        <location filename="mainwindow.cpp" line="827"/>
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>O programa parará agora para permitir a edição de quaisquer arquivos no diretório de trabalho (work). Clique em Sim para editar o menu de iniciação ou clique en Não para pular este passo e continuar a criação da imagem.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>Success</source>
         <translation>Sucesso</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>All finished!</source>
         <translation>Tudo terminado!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="779"/>
+        <location filename="mainwindow.cpp" line="841"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="924"/>
-        <source>About Snapshot</source>
-        <translation>Sobre o Snapshot</translation>
+        <location filename="mainwindow.cpp" line="942"/>
+        <source>About %1</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="925"/>
+        <location filename="mainwindow.cpp" line="943"/>
         <source>Version: </source>
         <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="927"/>
+        <location filename="mainwindow.cpp" line="944"/>
         <source>Program for creating a live-CD from the running system for antiX Linux</source>
         <translation>Programa para o Linux antiX para criar um meio de instalação externa / live CD a partir do sistema em execução.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="928"/>
+        <location filename="mainwindow.cpp" line="946"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Direitos de Autor (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="929"/>
-        <source>License</source>
-        <translation>Licença</translation>
+        <location filename="mainwindow.cpp" line="947"/>
+        <source>%1 License</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="930"/>
-        <source>Changelog</source>
-        <translation>Relatório de alterações</translation>
+        <location filename="mainwindow.cpp" line="962"/>
+        <source>%1 Help</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="948"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="980"/>
+        <location filename="mainwindow.cpp" line="970"/>
         <source>Select Snapshot Directory</source>
         <translation>Selecione o diretório Snapshot</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="999"/>
+        <location filename="mainwindow.cpp" line="989"/>
         <source>Confirmation</source>
         <translation>Confirmação</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="999"/>
+        <location filename="mainwindow.cpp" line="989"/>
         <source>Are you sure you want to quit the application?</source>
         <translation>Deseja mesmo sair da aplicação?</translation>
     </message>
@@ -441,7 +473,39 @@ removendo imagens anteriores e cópias guardadas:
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="main.cpp" line="81"/>
+        <location filename="about.cpp" line="32"/>
+        <source>License</source>
+        <translation>Licença</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>Relatório de alterações</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Fechar</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="75"/>
+        <location filename="main.cpp" line="86"/>
+        <source>Error</source>
+        <translation>Erro</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="76"/>
+        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="main.cpp" line="87"/>
         <source>You must run this program as root.</source>
         <translation>Tem que executar este programa como root.</translation>
     </message>
