@@ -3,223 +3,243 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
-        <location filename="mainwindow.cpp" line="49"/>
-        <location filename="mainwindow.cpp" line="113"/>
-        <location filename="mainwindow.cpp" line="788"/>
-        <location filename="mainwindow.cpp" line="925"/>
-        <location filename="ui_mainwindow.h" line="534"/>
+        <location filename="mainwindow.cpp" line="57"/>
+        <location filename="mainwindow.cpp" line="125"/>
+        <location filename="mainwindow.cpp" line="850"/>
+        <location filename="ui_mainwindow.h" line="549"/>
         <source>Snapshot</source>
         <translation>Snapshot</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="27"/>
-        <location filename="ui_mainwindow.h" line="535"/>
+        <location filename="mainwindow.ui" line="30"/>
+        <location filename="ui_mainwindow.h" line="550"/>
         <source>Snapshot location:</source>
         <translation>Snapshotets plats</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="40"/>
-        <location filename="ui_mainwindow.h" line="536"/>
+        <location filename="mainwindow.ui" line="43"/>
+        <location filename="ui_mainwindow.h" line="551"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot är ett verktyg som skapar en bootbar avbild (ISO) av ditt nuvarande system som du kan använda för lagring eller distribuering. Du kan fortsätta att arbeta med lätta program medan det körs.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="50"/>
-        <location filename="ui_mainwindow.h" line="537"/>
+        <location filename="mainwindow.ui" line="53"/>
+        <location filename="ui_mainwindow.h" line="552"/>
         <source>Used space on / (root) and /home partitions:</source>
         <translation>Använt utrymme på / (root) och /home partitioner:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="155"/>
-        <location filename="mainwindow.cpp" line="739"/>
-        <location filename="ui_mainwindow.h" line="541"/>
+        <location filename="mainwindow.ui" line="158"/>
+        <location filename="mainwindow.cpp" line="796"/>
+        <location filename="ui_mainwindow.h" line="556"/>
         <source>Snapshot name:</source>
         <translation>Snapshotets namn</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="162"/>
-        <location filename="ui_mainwindow.h" line="542"/>
+        <location filename="mainwindow.ui" line="165"/>
+        <location filename="ui_mainwindow.h" line="557"/>
         <source>Select a different snapshot directory</source>
         <translation>Välj en annan snapshot katalog</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="211"/>
-        <location filename="mainwindow.ui" line="229"/>
-        <location filename="mainwindow.ui" line="262"/>
-        <location filename="ui_mainwindow.h" line="544"/>
-        <location filename="ui_mainwindow.h" line="545"/>
-        <location filename="ui_mainwindow.h" line="546"/>
+        <location filename="mainwindow.ui" line="215"/>
+        <location filename="ui_mainwindow.h" line="561"/>
+        <source>lz4</source>
+        <translation>lz4</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="220"/>
+        <location filename="ui_mainwindow.h" line="562"/>
+        <source>lzo</source>
+        <translation>lzo</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="225"/>
+        <location filename="ui_mainwindow.h" line="563"/>
+        <source>gzip</source>
+        <translation>gzip</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="230"/>
+        <location filename="ui_mainwindow.h" line="564"/>
+        <source>xz</source>
+        <translation>xz</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="238"/>
+        <location filename="mainwindow.ui" line="313"/>
+        <location filename="ui_mainwindow.h" line="566"/>
+        <location filename="ui_mainwindow.h" line="568"/>
         <source>TextLabel</source>
         <translation>Text-Etikett</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="275"/>
-        <location filename="ui_mainwindow.h" line="547"/>
-        <source>Edit Configuration File</source>
-        <translation>Redigera Konfigurationsfil</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="309"/>
-        <location filename="ui_mainwindow.h" line="548"/>
+        <location filename="mainwindow.ui" line="281"/>
+        <location filename="ui_mainwindow.h" line="567"/>
         <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
         <translation>Du kan också undanta speciella kataloger genom att kryssa för de vanliga valen nedan, eller genom att klicka på knappen för att direkt redigera /usr/lib/iso-snapshot/snapshot-exclude.list.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="334"/>
-        <location filename="ui_mainwindow.h" line="549"/>
+        <location filename="mainwindow.ui" line="338"/>
+        <location filename="ui_mainwindow.h" line="569"/>
         <source>Downloads</source>
         <translation>Nerladdningar</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="341"/>
-        <location filename="ui_mainwindow.h" line="550"/>
+        <location filename="mainwindow.ui" line="345"/>
+        <location filename="ui_mainwindow.h" line="570"/>
         <source>Documents</source>
         <translation>Dokument</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
-        <location filename="ui_mainwindow.h" line="551"/>
+        <location filename="mainwindow.ui" line="352"/>
+        <location filename="ui_mainwindow.h" line="571"/>
         <source>All of the above</source>
         <translation>Alla ovan nämnda</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="355"/>
-        <location filename="ui_mainwindow.h" line="552"/>
+        <location filename="mainwindow.ui" line="359"/>
+        <location filename="ui_mainwindow.h" line="572"/>
         <source>Pictures</source>
         <translation>Bilder</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="362"/>
-        <location filename="ui_mainwindow.h" line="553"/>
+        <location filename="mainwindow.ui" line="366"/>
+        <location filename="ui_mainwindow.h" line="573"/>
         <source>Music</source>
         <translation>Musik</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="369"/>
-        <location filename="ui_mainwindow.h" line="554"/>
+        <location filename="mainwindow.ui" line="373"/>
+        <location filename="ui_mainwindow.h" line="574"/>
         <source>Desktop</source>
         <translation>Skrivbord</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="376"/>
-        <location filename="ui_mainwindow.h" line="555"/>
+        <location filename="mainwindow.ui" line="380"/>
+        <location filename="ui_mainwindow.h" line="575"/>
         <source>Videos</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="392"/>
-        <location filename="ui_mainwindow.h" line="556"/>
-        <source>Edit Exclusion File</source>
-        <translation>Redigera Exklusionsfil</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="422"/>
-        <location filename="ui_mainwindow.h" line="558"/>
+        <location filename="mainwindow.ui" line="418"/>
+        <location filename="ui_mainwindow.h" line="577"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the antiX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Detta alternativ kommer att återställa &quot;demo&quot; och &quot;root&quot; lösenorden till antiX Linux standardvärde och kommer inte att kopiera några personliga konton som skapats.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="425"/>
-        <location filename="ui_mainwindow.h" line="560"/>
+        <location filename="mainwindow.ui" line="421"/>
+        <location filename="ui_mainwindow.h" line="579"/>
         <source>Resetting accounts (for distribution to others)</source>
         <translation>Återställa konton (för distribution till andra)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="432"/>
-        <location filename="ui_mainwindow.h" line="561"/>
+        <location filename="mainwindow.ui" line="428"/>
+        <location filename="ui_mainwindow.h" line="580"/>
         <source>Type of snapshot:</source>
         <translation>Typ av snapshot:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="439"/>
-        <location filename="ui_mainwindow.h" line="562"/>
+        <location filename="mainwindow.ui" line="435"/>
+        <location filename="ui_mainwindow.h" line="581"/>
         <source>Preserving accounts (for personal backup)</source>
         <translation>Bevara konton (för personlig backup)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="551"/>
-        <location filename="ui_mainwindow.h" line="565"/>
-        <source>Quit application</source>
-        <translation>Avsluta programmet</translation>
+        <location filename="mainwindow.ui" line="461"/>
+        <location filename="ui_mainwindow.h" line="582"/>
+        <source>ISO compression scheme:</source>
+        <translation>ISO kompressions-schema:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="554"/>
-        <location filename="mainwindow.cpp" line="931"/>
-        <location filename="ui_mainwindow.h" line="567"/>
-        <source>Cancel</source>
-        <translation>Avbryt</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="561"/>
-        <location filename="ui_mainwindow.h" line="568"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
+        <location filename="mainwindow.ui" line="474"/>
+        <location filename="ui_mainwindow.h" line="583"/>
+        <source>Edit Exclusion File</source>
+        <translation>Redigera Exklusionsfil</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="571"/>
-        <location filename="ui_mainwindow.h" line="570"/>
+        <location filename="ui_mainwindow.h" line="586"/>
         <source>Display help </source>
         <translation>Visa hjälp</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="574"/>
-        <location filename="ui_mainwindow.h" line="572"/>
+        <location filename="ui_mainwindow.h" line="588"/>
         <source>Help</source>
         <translation>Hjälp</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="581"/>
-        <location filename="ui_mainwindow.h" line="573"/>
+        <location filename="ui_mainwindow.h" line="589"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="604"/>
-        <location filename="ui_mainwindow.h" line="575"/>
+        <location filename="mainwindow.ui" line="632"/>
+        <location filename="ui_mainwindow.h" line="592"/>
         <source>About this application</source>
         <translation>Om detta program</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="607"/>
-        <location filename="ui_mainwindow.h" line="577"/>
+        <location filename="mainwindow.ui" line="635"/>
+        <location filename="ui_mainwindow.h" line="594"/>
         <source>About...</source>
         <translation>Om...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="614"/>
-        <location filename="ui_mainwindow.h" line="578"/>
+        <location filename="mainwindow.ui" line="642"/>
+        <location filename="ui_mainwindow.h" line="595"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="652"/>
-        <location filename="ui_mainwindow.h" line="580"/>
+        <location filename="mainwindow.ui" line="658"/>
+        <location filename="ui_mainwindow.h" line="597"/>
+        <source>Quit application</source>
+        <translation>Avsluta programmet</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="661"/>
+        <location filename="ui_mainwindow.h" line="599"/>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="668"/>
+        <location filename="ui_mainwindow.h" line="600"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="684"/>
+        <location filename="ui_mainwindow.h" line="601"/>
         <source>Next</source>
         <translation>Nästa</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="678"/>
-        <location filename="ui_mainwindow.h" line="582"/>
+        <location filename="mainwindow.ui" line="726"/>
+        <location filename="ui_mainwindow.h" line="603"/>
         <source>Back</source>
         <translation>Bakåt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="203"/>
+        <location filename="mainwindow.cpp" line="239"/>
         <source>Used space on / (root): </source>
         <translation>Använt utrymme på / (root): </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="206"/>
+        <location filename="mainwindow.cpp" line="242"/>
         <source>Used space on /home: </source>
         <translation>Använt utrymme på/home: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="224"/>
+        <location filename="mainwindow.cpp" line="260"/>
         <source>Free space on %1, where snapshot folder is placed: </source>
         <translation>Fritt utrymme på %1, där snapshotkatalogen är placerad:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="226"/>
+        <location filename="mainwindow.cpp" line="262"/>
         <source>The free space should be sufficient to hold the compressed data from / and /home
 
       If necessary, you can create more available space
@@ -234,206 +254,218 @@ genom att avlägsna tidigare snapshots och sparade kopior:
 </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="246"/>
-        <location filename="mainwindow.cpp" line="247"/>
+        <location filename="mainwindow.cpp" line="282"/>
+        <location filename="mainwindow.cpp" line="283"/>
         <source>Installing </source>
         <translation>Installerar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
-        <location filename="mainwindow.cpp" line="555"/>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="592"/>
+        <location filename="mainwindow.cpp" line="608"/>
+        <location filename="mainwindow.cpp" line="802"/>
         <source>Error</source>
         <translation>Fel</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="256"/>
+        <location filename="mainwindow.cpp" line="291"/>
         <source>Could not install </source>
         <translation>Kunde inte installera</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
+        <location filename="mainwindow.cpp" line="321"/>
         <source>Building new initrd...</source>
         <translation>Skapar ny initrd...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="347"/>
         <source>Copying the new-iso filesystem...</source>
         <translation>Kopierar new-iso filsystem...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
+        <location filename="mainwindow.cpp" line="589"/>
         <source>Squashing filesystem...</source>
         <translation>Squashing filsystem...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="555"/>
+        <location filename="mainwindow.cpp" line="592"/>
         <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
         <translation>Kunde inte skapa linuxfs fil, var vänlig kontrollera om du har tillräckligt med utrymme på målpartitionen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="569"/>
+        <location filename="mainwindow.cpp" line="606"/>
         <source>Creating CD/DVD image file...</source>
         <translation>Skapar CD/DVD avbildsfil...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="608"/>
         <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
         <translation>Kunde inte skapa ISO fil, var vänlig kontrollera om du har tillräckligt med utrymme på målpartitionen.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="578"/>
+        <location filename="mainwindow.cpp" line="615"/>
         <source>Making hybrid iso</source>
         <translation>Skapar hybrid iso</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="599"/>
+        <location filename="mainwindow.cpp" line="628"/>
+        <source>MX Snapshot completed sucessfully!</source>
+        <translation>MX Snapshot fullföljdes framgångsrikt!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="629"/>
+        <location filename="mainwindow.cpp" line="630"/>
+        <source>Snapshot took %1 to finish.</source>
+        <translation>Snapshot tog %1 för att avslutas.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="631"/>
+        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
+        <translation>Tack för att du använder MX Snapshot, kör sedan MX Live USB Maker! </translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="644"/>
         <source>Making md5sum</source>
         <translation>Skapar md5 summa</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="622"/>
+        <location filename="mainwindow.cpp" line="668"/>
         <source>Cleaning...</source>
         <translation>Rensar...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="635"/>
-        <location filename="mainwindow.cpp" line="998"/>
+        <location filename="mainwindow.cpp" line="682"/>
+        <location filename="mainwindow.cpp" line="988"/>
         <source>Done</source>
         <translation>Klar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="713"/>
+        <location filename="mainwindow.cpp" line="770"/>
         <source>Please wait.</source>
         <translation>Var vänlig vänta.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="715"/>
+        <location filename="mainwindow.cpp" line="772"/>
         <source>Please wait. Calculating used disk space...</source>
         <translation>Var vänlig vänta. Beräknar använt hårddiskutrymme...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="730"/>
+        <location filename="mainwindow.cpp" line="787"/>
         <source>Settings</source>
         <translation>Inställningar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="736"/>
+        <location filename="mainwindow.cpp" line="793"/>
         <source>Snapshot will use the following settings:*</source>
         <translation>Snapshot kommer att använda följande inställningar.*</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="738"/>
+        <location filename="mainwindow.cpp" line="795"/>
         <source>- Snapshot directory:</source>
         <translation>-Snapshot katalog:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="740"/>
+        <location filename="mainwindow.cpp" line="797"/>
         <source>- Kernel to be used:</source>
         <translation>-Linuxkärna som ska användas:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="741"/>
-        <source>*These settings can be changed by editing: </source>
-        <translation>*Dessa inställningar kan ändras genom redigering:</translation>
+        <location filename="mainwindow.cpp" line="803"/>
+        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
+        <translation>Nuvarande kärna stöder inte vald kompressionsalgoritm, var vänlig redigera konfigurationsfilen och välj en annan algoritm.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="746"/>
+        <location filename="mainwindow.cpp" line="807"/>
         <source>Final chance</source>
         <translation>Sista chansen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="747"/>
+        <location filename="mainwindow.cpp" line="808"/>
         <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
         <translation>Snapshot har nu all information det behöver för att skapa en ISO av systemet du kör.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="748"/>
+        <location filename="mainwindow.cpp" line="809"/>
         <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
         <translation>Det kommer att ta en del tid att avsluta, beroende på storleken av det installerade systemet och din dators prestanda.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="749"/>
+        <location filename="mainwindow.cpp" line="810"/>
         <source>OK to start?</source>
         <translation>OK att börja?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="757"/>
+        <location filename="mainwindow.cpp" line="819"/>
         <source>Output</source>
         <translation>Output</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="764"/>
+        <location filename="mainwindow.cpp" line="826"/>
         <source>Edit Boot Menu</source>
         <translation>Redigera Boot Menu</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="765"/>
+        <location filename="mainwindow.cpp" line="827"/>
         <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
         <translation>Programmet kommer nu ta en paus för att låta dig redigera filer i arbetskatalogen. Välj Ja för att redigera boot menyn eller välj Nej för att hoppa över detta steg och fortsätta skapandet av snapshotet.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>Success</source>
         <translation>Det lyckades</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="778"/>
+        <location filename="mainwindow.cpp" line="840"/>
         <source>All finished!</source>
         <translation>Allt klart!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="779"/>
+        <location filename="mainwindow.cpp" line="841"/>
         <source>Close</source>
         <translation>Stäng</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="924"/>
-        <source>About Snapshot</source>
-        <translation>Om Snapshot</translation>
+        <location filename="mainwindow.cpp" line="942"/>
+        <source>About %1</source>
+        <translation>Om %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="925"/>
+        <location filename="mainwindow.cpp" line="943"/>
         <source>Version: </source>
         <translation>Version:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="927"/>
+        <location filename="mainwindow.cpp" line="944"/>
         <source>Program for creating a live-CD from the running system for antiX Linux</source>
         <translation>Program för att skapa en live-CD från systemet som körs för antX-Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="928"/>
+        <location filename="mainwindow.cpp" line="946"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="929"/>
-        <source>License</source>
-        <translation>Licens</translation>
+        <location filename="mainwindow.cpp" line="947"/>
+        <source>%1 License</source>
+        <translation>%1 Licens</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="930"/>
-        <source>Changelog</source>
-        <translation>Ändringslogg</translation>
+        <location filename="mainwindow.cpp" line="962"/>
+        <source>%1 Help</source>
+        <translation>%1 Hjälp</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="948"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Close</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="980"/>
+        <location filename="mainwindow.cpp" line="970"/>
         <source>Select Snapshot Directory</source>
         <translation>Välj Snapshot Katalog</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="999"/>
+        <location filename="mainwindow.cpp" line="989"/>
         <source>Confirmation</source>
         <translation>Bekräftelse</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="999"/>
+        <location filename="mainwindow.cpp" line="989"/>
         <source>Are you sure you want to quit the application?</source>
         <translation>Är du säker på att du vill avsluta programmet?</translation>
     </message>
@@ -441,7 +473,39 @@ genom att avlägsna tidigare snapshots och sparade kopior:
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="main.cpp" line="81"/>
+        <location filename="about.cpp" line="32"/>
+        <source>License</source>
+        <translation>Licens</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
+        <source>Changelog</source>
+        <translation>Ändringslogg</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="34"/>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <location filename="about.cpp" line="51"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Close</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="75"/>
+        <location filename="main.cpp" line="86"/>
+        <source>Error</source>
+        <translation>Fel</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="76"/>
+        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
+        <translation>Nuvarande kärna stöder inte Squashfs, kan inte fortsätta.</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="87"/>
         <source>You must run this program as root.</source>
         <translation>Du måste köra detta program som root</translation>
     </message>
